@@ -4,7 +4,7 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '2.4.69'
+__version__ = '2.4.78'
 
 # ----------------------------------------------------------------------------
 
@@ -14,6 +14,7 @@ from ccxt.pro.base.exchange import Exchange  # noqa: F401
 
 # CCXT Pro exchanges (now this is mainly used for importing exchanges in WS tests)
 
+from ccxt.pro.alpaca import alpaca                                        # noqa: F401
 from ccxt.pro.ascendex import ascendex                                    # noqa: F401
 from ccxt.pro.bequant import bequant                                      # noqa: F401
 from ccxt.pro.binance import binance                                      # noqa: F401
@@ -66,6 +67,7 @@ from ccxt.pro.zb import zb                                                # noqa
 from ccxt.pro.zipmex import zipmex                                        # noqa: F401
 
 exchanges = [
+    'alpaca',
     'ascendex',
     'bequant',
     'binance',
